==> haskell-commonmark-extensions-0.2.1.2-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 commonmark-extensions
version:              0.2.1.2
visibility:           public
id:                   commonmark-extensions-0.2.1.2-5Qiw83QXziOHqv4aAShflc
key:                  commonmark-extensions-0.2.1.2-5Qiw83QXziOHqv4aAShflc
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Pure Haskell commonmark parser.
description:
    This library provides some useful extensions to core commonmark
    syntax: smart quotes, definition lists, tables, footnotes, math,
    and more.

category:             Text
abi:                  73cb989192215302172ab9e83deb336f
exposed:              True
exposed-modules:
    Commonmark.Extensions Commonmark.Extensions.Attributes
    Commonmark.Extensions.AutoIdentifiers
    Commonmark.Extensions.Autolink Commonmark.Extensions.DefinitionList
    Commonmark.Extensions.Emoji Commonmark.Extensions.FancyList
    Commonmark.Extensions.Footnote Commonmark.Extensions.HardLineBreaks
    Commonmark.Extensions.ImplicitHeadingReferences
    Commonmark.Extensions.Math Commonmark.Extensions.PipeTable
    Commonmark.Extensions.RebaseRelativePaths
    Commonmark.Extensions.Smart Commonmark.Extensions.Strikethrough
    Commonmark.Extensions.Subscript Commonmark.Extensions.Superscript
    Commonmark.Extensions.TaskList Commonmark.Extensions.Wikilinks

import-dirs:          /usr/lib/ghc-9.0.1/site-local/commonmark-extensions-0.2.1.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/commonmark-extensions-0.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/commonmark-extensions-0.2.1.2

hs-libraries:         HScommonmark-extensions-0.2.1.2-5Qiw83QXziOHqv4aAShflc
depends:
    base-4.15.0.0 commonmark-0.2.1-KBNvs2hMyinWbzUZ8bxVA
    containers-0.6.4.1 emojis-0.1-J7GYQrMPfSAExkhwN0NeBn
    filepath-1.4.2.1 network-uri-2.6.4.1-3nEDxRoWlqR897WvDb69sm
    parsec-3.1.14.0 text-1.2.4.1 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-extensions/html/commonmark-extensions.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-commonmark-extensions-0.2.1.2-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 commonmark-extensions
version:              0.2.1.2
visibility:           public
id:                   commonmark-extensions-0.2.1.2-H7wFtTCRyeD2ObOeWuuxOD
key:                  commonmark-extensions-0.2.1.2-H7wFtTCRyeD2ObOeWuuxOD
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Pure Haskell commonmark parser.
description:
    This library provides some useful extensions to core commonmark
    syntax: smart quotes, definition lists, tables, footnotes, math,
    and more.

category:             Text
abi:                  6e6edd4db432ded16ca2aed842abf7d6
exposed:              True
exposed-modules:
    Commonmark.Extensions Commonmark.Extensions.Attributes
    Commonmark.Extensions.AutoIdentifiers
    Commonmark.Extensions.Autolink Commonmark.Extensions.DefinitionList
    Commonmark.Extensions.Emoji Commonmark.Extensions.FancyList
    Commonmark.Extensions.Footnote Commonmark.Extensions.HardLineBreaks
    Commonmark.Extensions.ImplicitHeadingReferences
    Commonmark.Extensions.Math Commonmark.Extensions.PipeTable
    Commonmark.Extensions.RebaseRelativePaths
    Commonmark.Extensions.Smart Commonmark.Extensions.Strikethrough
    Commonmark.Extensions.Subscript Commonmark.Extensions.Superscript
    Commonmark.Extensions.TaskList Commonmark.Extensions.Wikilinks

import-dirs:          /usr/lib/ghc-9.0.1/site-local/commonmark-extensions-0.2.1.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/commonmark-extensions-0.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/commonmark-extensions-0.2.1.2

hs-libraries:         HScommonmark-extensions-0.2.1.2-H7wFtTCRyeD2ObOeWuuxOD
depends:
    base-4.15.0.0 commonmark-0.2.1-6Ky24apWCeRLG7YQlv2geP
    containers-0.6.4.1 emojis-0.1-Hsw6dAVQhTbJiEQyDZreg7
    filepath-1.4.2.1 network-uri-2.6.4.1-DC1aot2K9KI32TlB2FcjFC
    parsec-3.1.14.0 text-1.2.4.1 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-extensions/html/commonmark-extensions.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
